#!/bin/bash

echo "🚀 开始设置 Twilio 翻译服务管理后台项目..."

# 检查 Node.js 是否安装
if ! command -v node &> /dev/null; then
    echo "❌ Node.js 未安装，请先安装 Node.js"
    exit 1
fi

# 显示 Node.js 版本
echo "✅ Node.js 版本: $(node --version)"
echo "✅ npm 版本: $(npm --version)"

# 安装项目依赖
echo "📦 安装项目依赖..."
npm install

# 安装缺失的依赖
echo "📦 安装 UI 组件库..."
npm install antd @ant-design/icons @ant-design/plots

echo "📦 安装路由相关依赖..."
npm install react-router-dom

echo "📦 安装开发依赖..."
npm install -D @types/react @types/react-dom

# 创建环境变量文件
if [ ! -f .env ]; then
    echo "📝 创建环境变量文件..."
    cp .env.example .env
    echo "✅ 已创建 .env 文件，请根据需要修改配置"
else
    echo "✅ .env 文件已存在"
fi

# 创建必要的目录
echo "📁 创建必要的目录结构..."
mkdir -p src/assets/images
mkdir -p src/assets/icons
mkdir -p public/assets

echo "🎉 项目设置完成！"
echo "📝 下一步操作："
echo "   1. 编辑 .env 文件配置环境变量"
echo "   2. 运行 npm run dev 启动开发服务器"
echo "   3. 访问 http://localhost:5173 查看应用" 