import { Layout, Menu, Typography } from 'antd';
import {
  DashboardOutlined,
  UserOutlined,
  PhoneOutlined,
  FileTextOutlined,
  CalendarOutlined,
  TranslationOutlined,
  CreditCardOutlined,
  SettingOutlined,
  AuditOutlined,
} from '@ant-design/icons';
import { useLocation, useNavigate } from 'react-router-dom';
import { useSidebar } from '@/store';
import { ROUTES } from '@/constants';

const { Sider } = Layout;
const { Title } = Typography;

interface MenuItem {
  key: string;
  icon: React.ReactNode;
  label: string;
  path: string;
}

const menuItems: MenuItem[] = [
  {
    key: 'dashboard',
    icon: <DashboardOutlined />,
    label: '仪表板',
    path: ROUTES.DASHBOARD,
  },
  {
    key: 'users',
    icon: <UserOutlined />,
    label: '用户管理',
    path: ROUTES.USERS,
  },
  {
    key: 'calls',
    icon: <PhoneOutlined />,
    label: '通话记录',
    path: ROUTES.CALLS,
  },
  {
    key: 'documents',
    icon: <FileTextOutlined />,
    label: '文档翻译',
    path: ROUTES.DOCUMENTS,
  },
  {
    key: 'appointments',
    icon: <CalendarOutlined />,
    label: '预约管理',
    path: ROUTES.APPOINTMENTS,
  },
  {
    key: 'translators',
    icon: <TranslationOutlined />,
    label: '译员管理',
    path: ROUTES.TRANSLATORS,
  },
  {
    key: 'payments',
    icon: <CreditCardOutlined />,
    label: '支付记录',
    path: ROUTES.PAYMENTS,
  },
  {
    key: 'settings',
    icon: <SettingOutlined />,
    label: '系统设置',
    path: ROUTES.SETTINGS,
  },
  {
    key: 'logs',
    icon: <AuditOutlined />,
    label: '系统日志',
    path: ROUTES.LOGS,
  },
];

const AppSidebar = () => {
  const location = useLocation();
  const navigate = useNavigate();
  const { sidebarCollapsed } = useSidebar();

  const selectedKey = menuItems.find(item => 
    location.pathname.startsWith(item.path)
  )?.key || 'dashboard';

  const handleMenuClick = ({ key }: { key: string }) => {
    const item = menuItems.find(item => item.key === key);
    if (item) {
      navigate(item.path);
    }
  };

  return (
    <Sider
      trigger={null}
      collapsible
      collapsed={sidebarCollapsed}
      width={240}
      style={{
        overflow: 'auto',
        height: '100vh',
        position: 'fixed',
        left: 0,
        top: 0,
        bottom: 0,
        background: '#001529',
      }}
    >
      <div style={{
        height: 64,
        display: 'flex',
        alignItems: 'center',
        justifyContent: 'center',
        borderBottom: '1px solid #1f1f1f',
      }}>
        {!sidebarCollapsed ? (
          <Title level={4} style={{ color: '#fff', margin: 0 }}>
            TranslatePro
          </Title>
        ) : (
          <Title level={4} style={{ color: '#fff', margin: 0 }}>
            TP
          </Title>
        )}
      </div>

      <Menu
        theme="dark"
        mode="inline"
        selectedKeys={[selectedKey]}
        onClick={handleMenuClick}
        style={{ borderRight: 0 }}
        items={menuItems.map(item => ({
          key: item.key,
          icon: item.icon,
          label: item.label,
        }))}
      />
    </Sider>
  );
};

export default AppSidebar; 