import { FC } from 'react';

const HomeScreen: FC = () => {
  const handleStartCall = (mode: string) => {
    alert(`您选择了${mode}模式`);
  };

  const handleUploadDocument = () => {
    alert('跳转到文档上传页面');
  };

  return (
    <div style={styles.container}>
      <div style={styles.scrollView}>
        {/* 用户信息卡片 */}
        <div style={styles.userCard}>
          <h2 style={styles.welcomeText}>欢迎回来！</h2>
          <p style={styles.userEmail}>user@example.com</p>
          <div style={styles.balanceContainer}>
            <span style={styles.balanceLabel}>剩余分钟数</span>
            <span style={styles.balanceValue}>120</span>
          </div>
        </div>

        {/* 快速操作 */}
        <div style={styles.section}>
          <h3 style={styles.sectionTitle}>快速开始</h3>
          <div style={styles.quickActions}>
            <button
              style={{...styles.actionButton, backgroundColor: '#4CAF50'}}
              onClick={() => handleStartCall('AI翻译')}
            >
              <span style={styles.actionButtonText}>🤖</span>
              <span style={styles.actionButtonLabel}>AI翻译</span>
            </button>

            <button
              style={{...styles.actionButton, backgroundColor: '#2196F3'}}
              onClick={() => handleStartCall('人工翻译')}
            >
              <span style={styles.actionButtonText}>👥</span>
              <span style={styles.actionButtonLabel}>人工翻译</span>
            </button>

            <button
              style={{...styles.actionButton, backgroundColor: '#FF9800'}}
              onClick={() => handleStartCall('视频翻译')}
            >
              <span style={styles.actionButtonText}>📹</span>
              <span style={styles.actionButtonLabel}>视频翻译</span>
            </button>

            <button
              style={{...styles.actionButton, backgroundColor: '#9C27B0'}}
              onClick={() => handleStartCall('手语翻译')}
            >
              <span style={styles.actionButtonText}>🤟</span>
              <span style={styles.actionButtonLabel}>手语翻译</span>
            </button>
          </div>
        </div>

        {/* 文档翻译 */}
        <div style={styles.section}>
          <button style={styles.documentButton} onClick={handleUploadDocument}>
            <span style={styles.documentButtonIcon}>📄</span>
            <div style={styles.documentButtonContent}>
              <span style={styles.documentButtonTitle}>文档翻译</span>
              <span style={styles.documentButtonSubtitle}>上传文档进行专业翻译</span>
            </div>
            <span style={styles.documentButtonArrow}>›</span>
          </button>
        </div>

        {/* 使用统计 */}
        <div style={styles.section}>
          <h3 style={styles.sectionTitle}>本月统计</h3>
          <div style={styles.statsContainer}>
            <div style={styles.statItem}>
              <span style={styles.statValue}>15</span>
              <span style={styles.statLabel}>通话次数</span>
            </div>
            <div style={styles.statItem}>
              <span style={styles.statValue}>240</span>
              <span style={styles.statLabel}>通话分钟</span>
            </div>
            <div style={styles.statItem}>
              <span style={styles.statValue}>$48</span>
              <span style={styles.statLabel}>总费用</span>
            </div>
          </div>
        </div>
      </div>
    </div>
  );
};

const styles = {
  container: {
    display: 'flex',
    flexDirection: 'column' as const,
    height: '100%',
    backgroundColor: '#f5f5f5',
  },
  scrollView: {
    flex: 1,
    padding: '16px',
    paddingBottom: '100px', // 为底部导航留空间
  },
  userCard: {
    backgroundColor: '#fff',
    padding: '20px',
    borderRadius: '12px',
    marginBottom: '16px',
    boxShadow: '0 2px 8px rgba(0, 0, 0, 0.1)',
  },
  welcomeText: {
    fontSize: '24px',
    fontWeight: 'bold',
    color: '#333',
    margin: '0 0 8px 0',
  },
  userEmail: {
    fontSize: '16px',
    color: '#666',
    margin: '0 0 16px 0',
  },
  balanceContainer: {
    display: 'flex',
    justifyContent: 'space-between',
    alignItems: 'center',
  },
  balanceLabel: {
    fontSize: '14px',
    color: '#666',
  },
  balanceValue: {
    fontSize: '24px',
    fontWeight: 'bold',
    color: '#1890ff',
  },
  section: {
    marginBottom: '24px',
  },
  sectionTitle: {
    fontSize: '18px',
    fontWeight: 'bold',
    color: '#333',
    margin: '0 0 16px 0',
  },
  quickActions: {
    display: 'grid',
    gridTemplateColumns: 'repeat(2, 1fr)',
    gap: '12px',
  },
  actionButton: {
    display: 'flex',
    flexDirection: 'column' as const,
    alignItems: 'center',
    padding: '20px',
    borderRadius: '12px',
    border: 'none',
    color: '#fff',
    cursor: 'pointer',
    transition: 'transform 0.2s ease',
  },
  actionButtonText: {
    fontSize: '32px',
    marginBottom: '8px',
  },
  actionButtonLabel: {
    fontSize: '14px',
    fontWeight: 'bold',
  },
  documentButton: {
    display: 'flex',
    alignItems: 'center',
    width: '100%',
    padding: '16px',
    backgroundColor: '#fff',
    border: 'none',
    borderRadius: '12px',
    cursor: 'pointer',
    boxShadow: '0 2px 8px rgba(0, 0, 0, 0.1)',
  },
  documentButtonIcon: {
    fontSize: '24px',
    marginRight: '16px',
  },
  documentButtonContent: {
    flex: 1,
    textAlign: 'left' as const,
  },
  documentButtonTitle: {
    display: 'block',
    fontSize: '16px',
    fontWeight: 'bold',
    color: '#333',
    marginBottom: '4px',
  },
  documentButtonSubtitle: {
    display: 'block',
    fontSize: '14px',
    color: '#666',
  },
  documentButtonArrow: {
    fontSize: '20px',
    color: '#999',
  },
  statsContainer: {
    display: 'grid',
    gridTemplateColumns: 'repeat(3, 1fr)',
    gap: '12px',
  },
  statItem: {
    display: 'flex',
    flexDirection: 'column' as const,
    alignItems: 'center',
    padding: '16px',
    backgroundColor: '#fff',
    borderRadius: '12px',
    boxShadow: '0 2px 8px rgba(0, 0, 0, 0.1)',
  },
  statValue: {
    fontSize: '24px',
    fontWeight: 'bold',
    color: '#1890ff',
    marginBottom: '4px',
  },
  statLabel: {
    fontSize: '12px',
    color: '#666',
    textAlign: 'center' as const,
  },
};

export default HomeScreen; 